import { defineStore } from 'pinia'
import config from '@/config'
import {type Zone} from '@/types'

export const useZoneEditorStore = defineStore('zoneEditor', {
  state: () => ({
    active: false,
    tiles: [] as number[][],
    tool: 'move',
    drawMode: 'tile',
    selectedTile: null,
    selectedWall: null,
    selectedDecoration: null,
    zoneSettings: null as Zone | null,
    zoneSettingsOpen: false
  }),
  actions: {
    toggleActive() {
      this.active = !this.active
    },
    setTiles(tiles: number[][]) {
      this.tiles = tiles
    },
    setTool(tool: string) {
      this.tool = tool
    },
    setDrawMode(mode: string) {
      this.drawMode = mode
    },
    setSelectedTile(tile: any) {
      this.selectedTile = tile
    },
    setSelectedWall(wall: any) {
      this.selectedWall = wall
    },
    setSelectedDecoration(decoration: any) {
      this.selectedDecoration = decoration
    },
    setZoneSettings(zone: Zone) {
      this.zoneSettings = zone
    },
    toggleZoneSettings() {
      this.zoneSettingsOpen = !this.zoneSettingsOpen
    },
    reset() {
      this.tiles = []
      this.tool = 'move'
      this.drawMode = 'tile'
      this.selectedTile = null
      this.selectedWall = null
      this.selectedDecoration = null
      this.zoneSettings = null
      this.zoneSettingsOpen = false
    }
  }
})